==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/GridRowEditEndedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridRowEditEndedEventArgsDescription } from "./GridRowEditEndedEventArgsDescription";
/**
 * @hidden
 */
export let GridRowEditEndedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridRowEditEndedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridRowEditEndedEventArgsDescriptionMetadata.a == null) {
                GridRowEditEndedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridRowEditEndedEventArgsDescriptionMetadata.c(GridRowEditEndedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridRowEditEndedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridRowEditEndedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Row", "Number:int");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            GridRowEditEndedEventArgsDescriptionMetadata.b(a);
            a.ad("GridRowEditEndedEventArgs", () => new GridRowEditEndedEventArgsDescription());
            a.ac("GridRowEditEndedEventArgs", GridRowEditEndedEventArgsDescriptionMetadata.a);
        }
    }
    GridRowEditEndedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridRowEditEndedEventArgsDescriptionMetadata, 'GridRowEditEndedEventArgsDescriptionMetadata');
    GridRowEditEndedEventArgsDescriptionMetadata.a = null;
    return GridRowEditEndedEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/GridRowEditEndedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridRowEditEndedEventArgsDescription } from "./GridRowEditEndedEventArgsDescription";
/**
 * @hidden
 */
export let GridRowEditEndedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridRowEditEndedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridRowEditEndedEventArgsDescriptionMetadata.a == null) {
                GridRowEditEndedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridRowEditEndedEventArgsDescriptionMetadata.c(GridRowEditEndedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridRowEditEndedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridRowEditEndedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Row", "Number:int");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            GridRowEditEndedEventArgsDescriptionMetadata.b(a);
            a.ae("GridRowEditEndedEventArgs", () => new GridRowEditEndedEventArgsDescription());
            a.ad("GridRowEditEndedEventArgs", GridRowEditEndedEventArgsDescriptionMetadata.a);
        }
    }
    GridRowEditEndedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridRowEditEndedEventArgsDescriptionMetadata, 'GridRowEditEndedEventArgsDescriptionMetadata');
    GridRowEditEndedEventArgsDescriptionMetadata.a = null;
    return GridRowEditEndedEventArgsDescriptionMetadata;
})();
